Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormattpiwik <matthieu.aubry@gmail.com>2011-02-12 16:34:53 +0300
committermattpiwik <matthieu.aubry@gmail.com>2011-02-12 16:34:53 +0300
commit0e3252517cf23823cbb231250ab1839679ae6808 (patch)
tree3296cadc2ee9f6b939034b9d26d39f0ad83b362f /plugins/Proxy
parent8518cb19b351e5d9be1d6d1951da4a8f0044cb96 (diff)
Refs #1736
* API functions returning data now have a new optional 'segment' parameter. segment can define a Visitor segment dynamically that will be applied to the report. For example, &segment=country==FR;actions>=3 (AND, OR supported. Only == and != supported currently, but easy to add more) * For API requests with a segment parameter, the reports will now be processed on the fly, and only the requested plugin report will be archived. * All plugins now define the 'segments', with a name, category, SQL field, filter, etc. * Simplifying archiving code a bit * Fixes #2069 Exit rate computation * New widget: lists the Top Keywords for a page URL, Widgets for a website only. Maybe later we could create a widget category "For your site"? * This widget is pretty cool SEO wise, but maybe the PHP snippet should do caching (not so good hitting the API on each page view... but why not?) * still to do! git-svn-id: http://dev.piwik.org/svn/trunk@3870 59fd770c-687e-43c8-a1e3-f5a4ff64c105
Diffstat (limited to 'plugins/Proxy')
-rw-r--r--plugins/Proxy/Controller.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/Proxy/Controller.php b/plugins/Proxy/Controller.php
index a27164f7b2..8996c26c8f 100644
--- a/plugins/Proxy/Controller.php
+++ b/plugins/Proxy/Controller.php
@@ -109,15 +109,15 @@ class Piwik_Proxy_Controller extends Piwik_Controller
/**
* Output redirection page instead of linking directly to avoid
* exposing the referer on the Piwik demo.
*
* @param string $url (via $_GET)
*/
public function redirect()
{
- // validate referer
- $referer = Piwik_Url::getReferer();
- if(!empty($referer) && (Piwik_Url::getLocalReferer() === false))
+ // validate referrer
+ $referrer = Piwik_Url::getReferer();
+ if(!empty($referrer) && (Piwik_Url::getLocalReferer() === false))
{
exit;
}
@@ -109,15 +109,15 @@ class Piwik_Proxy_Controller extends Piwik_Controller
/**
* Output redirection page instead of linking directly to avoid
- * exposing the referer on the Piwik demo.
+ * exposing the referrer on the Piwik demo.
*
* @param string $url (via $_GET)